@@ -14,6 +14,14 @@ $expectedFailures = [
     'Top-level document validity: Bad $date (number, not string or hash)' => 'Legacy extended JSON $date syntax uses numbers (CDRIVER-2223)',
 ];
 
+$for64bitOnly = [
+    /* Note: Although 64-bit integers be represented by the Int64 class, these
+     * tests fail on 32-bit platforms due to json_canonicalize() roundtripping
+     * values through PHP, which converts large integers to floats. */
+    'Int64 type: MinValue' => "Can't represent 64-bit ints on a 32-bit platform",
+    'Int64 type: MaxValue' => "Can't represent 64-bit ints on a 32-bit platform",
+];
+
 $outputPath = realpath(__DIR__ . '/../tests') . '/bson-corpus/';
 
 if ( ! is_dir($outputPath) && ! mkdir($outputPath, 0755, true)) {
@@ -38,16 +46,11 @@ foreach (array_slice($argv, 1) as $inputFile) {
         continue;
     }
 
-    if ( ! empty($test['deprecated'])) {
-        printf("Skipping deprecated test file: %s\n", $inputFile);
-        continue;
-    }
-
     if ( ! empty($test['valid'])) {
         foreach ($test['valid'] as $i => $case) {
             $outputFile = sprintf('%s-valid-%03d.phpt', pathinfo($inputFile, PATHINFO_FILENAME), $i + 1);
             try {
-                $output = renderPhpt(getParamsForValid($test, $case), $expectedFailures);
+                $output = renderPhpt(getParamsForValid($test, $case), $expectedFailures, $for64bitOnly);
             } catch (Exception $e) {
                 printf("Error processing valid[%d] in %s: %s\n", $i, $inputFile, $e->getMessage());
                 continue;
@@ -64,7 +67,7 @@ foreach (array_slice($argv, 1) as $inputFile) {
         foreach ($test['decodeErrors'] as $i => $case) {
             $outputFile = sprintf('%s-decodeError-%03d.phpt', pathinfo($inputFile, PATHINFO_FILENAME), $i + 1);
             try {
-                $output = renderPhpt(getParamsForDecodeError($test, $case), $expectedFailures);
+                $output = renderPhpt(getParamsForDecodeError($test, $case), $expectedFailures, $for64bitOnly);
             } catch (Exception $e) {
                 printf("Error processing decodeErrors[%d] in %s: %s\n", $i, $inputFile, $e->getMessage());
                 continue;
@@ -81,7 +84,7 @@ foreach (array_slice($argv, 1) as $inputFile) {
         foreach ($test['parseErrors'] as $i => $case) {
             $outputFile = sprintf('%s-parseError-%03d.phpt', pathinfo($inputFile, PATHINFO_FILENAME), $i + 1);
             try {
-                $output = renderPhpt(getParamsForParseError($test, $case), $expectedFailures);
+                $output = renderPhpt(getParamsForParseError($test, $case), $expectedFailures, $for64bitOnly);
             } catch (Exception $e) {
                 printf("Error processing parseErrors[%d] in %s: %s\n", $i, $inputFile, $e->getMessage());
                 continue;
@@ -268,16 +271,19 @@ function getParamsForParseError(array $test, array $case)
     ];
 }
 
-function renderPhpt(array $params, array $expectedFailures)
+function renderPhpt(array $params, array $expectedFailures, array $for64bitOnly)
 {
      $params['%XFAIL%'] = isset($expectedFailures[$params['%NAME%']])
         ? "--XFAIL--\n" . $expectedFailures[$params['%NAME%']] . "\n"
         : '';
+     $params['%SKIPIF%'] = isset($for64bitOnly[$params['%NAME%']])
+        ? "--SKIPIF--\n" . "<?php if (PHP_INT_SIZE !== 8) { die(\"skip {$for64bitOnly[$params['%NAME%']]}\"); } ?>" . "\n"
+        : '';
 
     $template = <<< 'TEMPLATE'
 --TEST--
 %NAME%
-%XFAIL%--DESCRIPTION--
+%XFAIL%%SKIPIF%--DESCRIPTION--
 Generated by scripts/convert-bson-corpus-tests.php
 
 DO NOT EDIT THIS FILE
