@@ -15,7 +15,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 #include <php.h>
@@ -26,9 +26,25 @@
 #include "php_phongo.h"
 #include "php_bson.h"
 
-zend_class_entry *php_phongo_cursor_ce;
+zend_class_entry* php_phongo_cursor_ce;
 
-static void php_phongo_cursor_free_current(php_phongo_cursor_t *cursor) /* {{{ */
+/* Check if the cursor is exhausted (i.e. ID is zero) and free any reference to
+ * the session. Calling this function during iteration will allow an implicit
+ * session to return to the pool immediately after a getMore indicates that the
+ * server has no more results to return. */
+static void php_phongo_cursor_free_session_if_exhausted(php_phongo_cursor_t* cursor) /* {{{ */
+{
+	if (mongoc_cursor_get_id(cursor->cursor)) {
+		return;
+	}
+
+	if (!Z_ISUNDEF(cursor->session)) {
+		zval_ptr_dtor(&cursor->session);
+		ZVAL_UNDEF(&cursor->session);
+	}
+} /* }}} */
+
+static void php_phongo_cursor_free_current(php_phongo_cursor_t* cursor) /* {{{ */
 {
 	if (!Z_ISUNDEF(cursor->visitor_data.zchild)) {
 		zval_ptr_dtor(&cursor->visitor_data.zchild);
@@ -37,15 +53,15 @@ static void php_phongo_cursor_free_current(php_phongo_cursor_t *cursor) /* {{{ *
 } /* }}} */
 
 /* {{{ MongoDB\Driver\Cursor iterator handlers */
-static void php_phongo_cursor_iterator_dtor(zend_object_iterator *iter TSRMLS_DC) /* {{{ */
+static void php_phongo_cursor_iterator_dtor(zend_object_iterator* iter TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursor_iterator *cursor_it = (php_phongo_cursor_iterator *)iter;
+	php_phongo_cursor_iterator* cursor_it = (php_phongo_cursor_iterator*) iter;
 
 	if (!Z_ISUNDEF(cursor_it->intern.data)) {
 #if PHP_VERSION_ID >= 70000
 		zval_ptr_dtor(&cursor_it->intern.data);
 #else
-		zval_ptr_dtor((zval**)&cursor_it->intern.data);
+		zval_ptr_dtor((zval**) &cursor_it->intern.data);
 		cursor_it->intern.data = NULL;
 #endif
 	}
@@ -55,9 +71,9 @@ static void php_phongo_cursor_iterator_dtor(zend_object_iterator *iter TSRMLS_DC
 #endif
 } /* }}} */
 
-static int php_phongo_cursor_iterator_valid(zend_object_iterator *iter TSRMLS_DC) /* {{{ */
+static int php_phongo_cursor_iterator_valid(zend_object_iterator* iter TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursor_t *cursor = ((php_phongo_cursor_iterator *)iter)->cursor;
+	php_phongo_cursor_t* cursor = ((php_phongo_cursor_iterator*) iter)->cursor;
 
 	if (!Z_ISUNDEF(cursor->visitor_data.zchild)) {
 		return SUCCESS;
@@ -66,42 +82,50 @@ static int php_phongo_cursor_iterator_valid(zend_object_iterator *iter TSRMLS_DC
 	return FAILURE;
 } /* }}} */
 
-static void php_phongo_cursor_iterator_get_current_key(zend_object_iterator *iter, zval *key TSRMLS_DC) /* {{{ */
+static void php_phongo_cursor_iterator_get_current_key(zend_object_iterator* iter, zval* key TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursor_t *cursor = ((php_phongo_cursor_iterator *)iter)->cursor;
+	php_phongo_cursor_t* cursor = ((php_phongo_cursor_iterator*) iter)->cursor;
 
 	ZVAL_LONG(key, cursor->current);
 } /* }}} */
 
 #if PHP_VERSION_ID < 70000
-static void php_phongo_cursor_iterator_get_current_data(zend_object_iterator *iter, zval ***data TSRMLS_DC) /* {{{ */
+static void php_phongo_cursor_iterator_get_current_data(zend_object_iterator* iter, zval*** data TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursor_t *cursor = ((php_phongo_cursor_iterator *)iter)->cursor;
+	php_phongo_cursor_t* cursor = ((php_phongo_cursor_iterator*) iter)->cursor;
 
 	*data = &cursor->visitor_data.zchild;
 } /* }}} */
 #else
-static zval* php_phongo_cursor_iterator_get_current_data(zend_object_iterator *iter) /* {{{ */
+static zval* php_phongo_cursor_iterator_get_current_data(zend_object_iterator* iter) /* {{{ */
 {
-	php_phongo_cursor_t *cursor = ((php_phongo_cursor_iterator *)iter)->cursor;
+	php_phongo_cursor_t* cursor = ((php_phongo_cursor_iterator*) iter)->cursor;
 
 	return &cursor->visitor_data.zchild;
 } /* }}} */
 #endif
 
-static void php_phongo_cursor_iterator_move_forward(zend_object_iterator *iter TSRMLS_DC) /* {{{ */
+static void php_phongo_cursor_iterator_move_forward(zend_object_iterator* iter TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursor_iterator *cursor_it = (php_phongo_cursor_iterator *)iter;
-	php_phongo_cursor_t        *cursor = cursor_it->cursor;
-	const bson_t               *doc;
+	php_phongo_cursor_iterator* cursor_it = (php_phongo_cursor_iterator*) iter;
+	php_phongo_cursor_t*        cursor    = cursor_it->cursor;
+	const bson_t*               doc;
 
 	php_phongo_cursor_free_current(cursor);
-	cursor->current++;
+
+	/* If the cursor has already advanced, increment its position. Otherwise,
+	 * the first call to mongoc_cursor_next() will be made below and we should
+	 * leave its position at zero. */
+	if (cursor->advanced) {
+		cursor->current++;
+	} else {
+		cursor->advanced = true;
+	}
 
 	if (mongoc_cursor_next(cursor->cursor, &doc)) {
 		php_phongo_bson_to_zval_ex(bson_get_data(doc), doc->len, &cursor->visitor_data);
 	} else {
-		bson_error_t error;
+		bson_error_t error = { 0 };
 
 		if (mongoc_cursor_error(cursor->cursor, &error)) {
 			/* Intentionally not destroying the cursor as it will happen
@@ -109,13 +133,25 @@ static void php_phongo_cursor_iterator_move_forward(zend_object_iterator *iter T
 			phongo_throw_exception_from_bson_error_t(&error TSRMLS_CC);
 		}
 	}
+
+	php_phongo_cursor_free_session_if_exhausted(cursor);
 } /* }}} */
 
-static void php_phongo_cursor_iterator_rewind(zend_object_iterator *iter TSRMLS_DC) /* {{{ */
+static void php_phongo_cursor_iterator_rewind(zend_object_iterator* iter TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursor_iterator *cursor_it = (php_phongo_cursor_iterator *)iter;
-	php_phongo_cursor_t        *cursor = cursor_it->cursor;
-	const bson_t               *doc;
+	php_phongo_cursor_iterator* cursor_it = (php_phongo_cursor_iterator*) iter;
+	php_phongo_cursor_t*        cursor    = cursor_it->cursor;
+	const bson_t*               doc;
+
+	/* If the cursor was never advanced (e.g. command cursor), do so now */
+	if (!cursor->advanced) {
+		cursor->advanced = true;
+
+		if (!phongo_cursor_advance_and_check_for_error(cursor->cursor TSRMLS_CC)) {
+			/* Exception should already have been thrown */
+			return;
+		}
+	}
 
 	if (cursor->current > 0) {
 		phongo_throw_exception(PHONGO_ERROR_LOGIC TSRMLS_CC, "Cursors cannot rewind after starting iteration");
@@ -129,6 +165,8 @@ static void php_phongo_cursor_iterator_rewind(zend_object_iterator *iter TSRMLS_
 	if (doc) {
 		php_phongo_bson_to_zval_ex(bson_get_data(doc), doc->len, &cursor->visitor_data);
 	}
+
+	php_phongo_cursor_free_session_if_exhausted(cursor);
 } /* }}} */
 
 static zend_object_iterator_funcs php_phongo_cursor_iterator_funcs = {
@@ -141,10 +179,10 @@ static zend_object_iterator_funcs php_phongo_cursor_iterator_funcs = {
 	NULL /* invalidate_current is not used */
 };
 
-static zend_object_iterator *php_phongo_cursor_get_iterator(zend_class_entry *ce, zval *object, int by_ref TSRMLS_DC) /* {{{ */
+static zend_object_iterator* php_phongo_cursor_get_iterator(zend_class_entry* ce, zval* object, int by_ref TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursor_iterator *cursor_it = NULL;
-	php_phongo_cursor_t *cursor = Z_CURSOR_OBJ_P(object);
+	php_phongo_cursor_iterator* cursor_it = NULL;
+	php_phongo_cursor_t*        cursor    = Z_CURSOR_OBJ_P(object);
 
 	if (by_ref) {
 		zend_error(E_ERROR, "An iterator cannot be used with foreach by reference");
@@ -166,10 +204,10 @@ static zend_object_iterator *php_phongo_cursor_get_iterator(zend_class_entry *ce
 	ZVAL_COPY(&cursor_it->intern.data, object);
 #else
 	Z_ADDREF_P(object);
-	cursor_it->intern.data  = (void*)object;
+	cursor_it->intern.data = (void*) object;
 #endif
 	cursor_it->intern.funcs = &php_phongo_cursor_iterator_funcs;
-	cursor_it->cursor = cursor;
+	cursor_it->cursor       = cursor;
 	/* cursor_it->current should already be allocated to zero */
 
 	php_phongo_cursor_free_current(cursor_it->cursor);
@@ -182,12 +220,13 @@ static zend_object_iterator *php_phongo_cursor_get_iterator(zend_class_entry *ce
    Sets a type map to use for BSON unserialization */
 static PHP_METHOD(Cursor, setTypeMap)
 {
-	php_phongo_cursor_t *intern;
-	php_phongo_bson_state     state = PHONGO_BSON_STATE_INITIALIZER;
-	zval                     *typemap = NULL;
-	bool                      restore_current_element = false;
-	SUPPRESS_UNUSED_WARNING(return_value) SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
-
+	php_phongo_cursor_t*  intern;
+	php_phongo_bson_state state                   = PHONGO_BSON_STATE_INITIALIZER;
+	zval*                 typemap                 = NULL;
+	bool                  restore_current_element = false;
+	SUPPRESS_UNUSED_WARNING(return_value)
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_CURSOR_OBJ_P(getThis());
 
@@ -206,22 +245,24 @@ static PHP_METHOD(Cursor, setTypeMap)
 		restore_current_element = true;
 	}
 
+	php_phongo_bson_typemap_dtor(&intern->visitor_data.map);
+
 	intern->visitor_data = state;
 
 	/* If the cursor has a current element, we just freed it and should restore
 	 * it with a new type map applied. */
 	if (restore_current_element && mongoc_cursor_current(intern->cursor)) {
-		const bson_t *doc = mongoc_cursor_current(intern->cursor);
+		const bson_t* doc = mongoc_cursor_current(intern->cursor);
 
 		php_phongo_bson_to_zval_ex(bson_get_data(doc), doc->len, &intern->visitor_data);
 	}
 } /* }}} */
 
-static int php_phongo_cursor_to_array_apply(zend_object_iterator *iter, void *puser TSRMLS_DC) /* {{{ */
+static int php_phongo_cursor_to_array_apply(zend_object_iterator* iter, void* puser TSRMLS_DC) /* {{{ */
 {
 #if PHP_VERSION_ID >= 70000
-	zval *data;
-	zval *return_value = (zval*)puser;
+	zval* data;
+	zval* return_value = (zval*) puser;
 
 	data = iter->funcs->get_current_data(iter TSRMLS_CC);
 
@@ -234,8 +275,8 @@ static int php_phongo_cursor_to_array_apply(zend_object_iterator *iter, void *pu
 	Z_TRY_ADDREF_P(data);
 	add_next_index_zval(return_value, data);
 #else
-	zval **data;
-	zval *return_value = (zval*)puser;
+	zval** data;
+	zval* return_value = (zval*) puser;
 
 	iter->funcs->get_current_data(iter, &data TSRMLS_CC);
 
@@ -256,7 +297,8 @@ static int php_phongo_cursor_to_array_apply(zend_object_iterator *iter, void *pu
    Returns an array of all result documents for this cursor */
 static PHP_METHOD(Cursor, toArray)
 {
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	if (zend_parse_parameters_none() == FAILURE) {
 		return;
@@ -264,7 +306,7 @@ static PHP_METHOD(Cursor, toArray)
 
 	array_init(return_value);
 
-	if (spl_iterator_apply(getThis(), php_phongo_cursor_to_array_apply, (void*)return_value TSRMLS_CC) != SUCCESS) {
+	if (spl_iterator_apply(getThis(), php_phongo_cursor_to_array_apply, (void*) return_value TSRMLS_CC) != SUCCESS) {
 		zval_dtor(return_value);
 		RETURN_NULL();
 	}
@@ -274,9 +316,9 @@ static PHP_METHOD(Cursor, toArray)
    Returns the CursorId for this cursor */
 static PHP_METHOD(Cursor, getId)
 {
-	php_phongo_cursor_t      *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
-
+	php_phongo_cursor_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_CURSOR_OBJ_P(getThis());
 
@@ -291,9 +333,9 @@ static PHP_METHOD(Cursor, getId)
    Returns the Server object to which this cursor is attached */
 static PHP_METHOD(Cursor, getServer)
 {
-	php_phongo_cursor_t *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
-
+	php_phongo_cursor_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_CURSOR_OBJ_P(getThis());
 
@@ -308,9 +350,9 @@ static PHP_METHOD(Cursor, getServer)
    Checks if a cursor is still alive */
 static PHP_METHOD(Cursor, isDead)
 {
-	php_phongo_cursor_t      *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
-
+	php_phongo_cursor_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_CURSOR_OBJ_P(getThis());
 
@@ -318,7 +360,7 @@ static PHP_METHOD(Cursor, isDead)
 		return;
 	}
 
-	RETURN_BOOL(!mongoc_cursor_is_alive(intern->cursor));
+	RETURN_BOOL(!mongoc_cursor_more(intern->cursor));
 } /* }}} */
 
 /* {{{ MongoDB\Driver\Cursor function entries */
@@ -330,23 +372,25 @@ ZEND_BEGIN_ARG_INFO_EX(ai_Cursor_void, 0, 0, 0)
 ZEND_END_ARG_INFO()
 
 static zend_function_entry php_phongo_cursor_me[] = {
-	PHP_ME(Cursor, setTypeMap, ai_Cursor_setTypeMap, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(Cursor, toArray, ai_Cursor_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(Cursor, getId, ai_Cursor_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(Cursor, getServer, ai_Cursor_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(Cursor, isDead, ai_Cursor_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_Cursor_void, ZEND_ACC_PRIVATE|ZEND_ACC_FINAL)
-	ZEND_NAMED_ME(__wakeup, PHP_FN(MongoDB_disabled___wakeup), ai_Cursor_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
+	/* clang-format off */
+	PHP_ME(Cursor, setTypeMap, ai_Cursor_setTypeMap, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(Cursor, toArray, ai_Cursor_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(Cursor, getId, ai_Cursor_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(Cursor, getServer, ai_Cursor_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(Cursor, isDead, ai_Cursor_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_Cursor_void, ZEND_ACC_PRIVATE | ZEND_ACC_FINAL)
+	ZEND_NAMED_ME(__wakeup, PHP_FN(MongoDB_disabled___wakeup), ai_Cursor_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
 	PHP_FE_END
+	/* clang-format on */
 };
 /* }}} */
 
 /* {{{ MongoDB\Driver\Cursor object handlers */
 static zend_object_handlers php_phongo_handler_cursor;
 
-static void php_phongo_cursor_free_object(phongo_free_object_arg *object TSRMLS_DC) /* {{{ */
+static void php_phongo_cursor_free_object(phongo_free_object_arg* object TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursor_t *intern = Z_OBJ_CURSOR(object);
+	php_phongo_cursor_t* intern = Z_OBJ_CURSOR(object);
 
 	zend_object_std_dtor(&intern->std TSRMLS_CC);
 
@@ -374,6 +418,12 @@ static void php_phongo_cursor_free_object(phongo_free_object_arg *object TSRMLS_
 		zval_ptr_dtor(&intern->read_preference);
 	}
 
+	if (!Z_ISUNDEF(intern->session)) {
+		zval_ptr_dtor(&intern->session);
+	}
+
+	php_phongo_bson_typemap_dtor(&intern->visitor_data.map);
+
 	php_phongo_cursor_free_current(intern);
 
 #if PHP_VERSION_ID < 70000
@@ -381,9 +431,9 @@ static void php_phongo_cursor_free_object(phongo_free_object_arg *object TSRMLS_
 #endif
 } /* }}} */
 
-static phongo_create_object_retval php_phongo_cursor_create_object(zend_class_entry *class_type TSRMLS_DC) /* {{{ */
+static phongo_create_object_retval php_phongo_cursor_create_object(zend_class_entry* class_type TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursor_t *intern = NULL;
+	php_phongo_cursor_t* intern = NULL;
 
 	intern = PHONGO_ALLOC_OBJECT_T(php_phongo_cursor_t, class_type);
 
@@ -405,20 +455,15 @@ static phongo_create_object_retval php_phongo_cursor_create_object(zend_class_en
 #endif
 } /* }}} */
 
-static HashTable *php_phongo_cursor_get_debug_info(zval *object, int *is_temp TSRMLS_DC) /* {{{ */
+static HashTable* php_phongo_cursor_get_debug_info(zval* object, int* is_temp TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursor_t    *intern;
-#if PHP_VERSION_ID >= 70000
-	zval                    retval;
-#else
-	zval                    retval = zval_used_for_init;
-#endif
-
+	php_phongo_cursor_t* intern;
+	zval                 retval = ZVAL_STATIC_INIT;
 
 	*is_temp = 1;
-	intern = Z_CURSOR_OBJ_P(object);
+	intern   = Z_CURSOR_OBJ_P(object);
 
-	array_init_size(&retval, 9);
+	array_init_size(&retval, 10);
 
 	if (intern->database) {
 		ADD_ASSOC_STRING(&retval, "database", intern->database);
@@ -468,14 +513,26 @@ static HashTable *php_phongo_cursor_get_debug_info(zval *object, int *is_temp TS
 		ADD_ASSOC_NULL_EX(&retval, "readPreference");
 	}
 
-	ADD_ASSOC_BOOL_EX(&retval, "isDead", !mongoc_cursor_is_alive(intern->cursor));
+	if (!Z_ISUNDEF(intern->session)) {
+#if PHP_VERSION_ID >= 70000
+		ADD_ASSOC_ZVAL_EX(&retval, "session", &intern->session);
+		Z_ADDREF(intern->session);
+#else
+		ADD_ASSOC_ZVAL_EX(&retval, "session", intern->session);
+		Z_ADDREF_P(intern->session);
+#endif
+	} else {
+		ADD_ASSOC_NULL_EX(&retval, "session");
+	}
+
+	ADD_ASSOC_BOOL_EX(&retval, "isDead", !mongoc_cursor_more(intern->cursor));
 
 	ADD_ASSOC_LONG_EX(&retval, "currentIndex", intern->current);
 
 	if (!Z_ISUNDEF(intern->visitor_data.zchild)) {
 #if PHP_VERSION_ID >= 70000
 		ADD_ASSOC_ZVAL_EX(&retval, "currentDocument", &intern->visitor_data.zchild);
-		/*Z_ADDREF(intern->visitor_data.zchild);*/
+		Z_ADDREF(intern->visitor_data.zchild);
 #else
 		ADD_ASSOC_ZVAL_EX(&retval, "currentDocument", intern->visitor_data.zchild);
 		Z_ADDREF_P(intern->visitor_data.zchild);
@@ -491,7 +548,7 @@ static HashTable *php_phongo_cursor_get_debug_info(zval *object, int *is_temp TS
 		phongo_server_init(&server, intern->client, intern->server_id TSRMLS_CC);
 		ADD_ASSOC_ZVAL_EX(&retval, "server", &server);
 #else
-		zval *server = NULL;
+		zval* server = NULL;
 
 		MAKE_STD_ZVAL(server);
 		phongo_server_init(server, intern->client, intern->server_id TSRMLS_CC);
@@ -509,7 +566,7 @@ void php_phongo_cursor_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	zend_class_entry ce;
 
 	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\Driver", "Cursor", php_phongo_cursor_me);
-	php_phongo_cursor_ce = zend_register_internal_class(&ce TSRMLS_CC);
+	php_phongo_cursor_ce                = zend_register_internal_class(&ce TSRMLS_CC);
 	php_phongo_cursor_ce->create_object = php_phongo_cursor_create_object;
 	PHONGO_CE_FINAL(php_phongo_cursor_ce);
 	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_cursor_ce);
@@ -519,7 +576,7 @@ void php_phongo_cursor_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	php_phongo_handler_cursor.get_debug_info = php_phongo_cursor_get_debug_info;
 #if PHP_VERSION_ID >= 70000
 	php_phongo_handler_cursor.free_obj = php_phongo_cursor_free_object;
-	php_phongo_handler_cursor.offset = XtOffsetOf(php_phongo_cursor_t, std);
+	php_phongo_handler_cursor.offset   = XtOffsetOf(php_phongo_cursor_t, std);
 #endif
 
 	zend_class_implements(php_phongo_cursor_ce TSRMLS_CC, 1, zend_ce_traversable);
