@@ -15,7 +15,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 #include <php.h>
@@ -24,16 +24,17 @@
 #include "phongo_compat.h"
 #include "php_phongo.h"
 
-zend_class_entry *php_phongo_cursorid_ce;
+zend_class_entry* php_phongo_cursorid_ce;
 
 /* {{{ proto string MongoDB\Driver\CursorId::__toString()
    Returns the string representation of the CursorId */
 static PHP_METHOD(CursorId, __toString)
 {
-	php_phongo_cursorid_t    *intern;
-	char *tmp;
-	int tmp_len;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_cursorid_t* intern;
+	char*                  tmp;
+	int                    tmp_len;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_CURSORID_OBJ_P(getThis());
 
@@ -51,19 +52,21 @@ ZEND_BEGIN_ARG_INFO_EX(ai_CursorId_void, 0, 0, 0)
 ZEND_END_ARG_INFO()
 
 static zend_function_entry php_phongo_cursorid_me[] = {
-	PHP_ME(CursorId, __toString, ai_CursorId_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_CursorId_void, ZEND_ACC_PRIVATE|ZEND_ACC_FINAL)
-	ZEND_NAMED_ME(__wakeup, PHP_FN(MongoDB_disabled___wakeup), ai_CursorId_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
+	/* clang-format off */
+	PHP_ME(CursorId, __toString, ai_CursorId_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_CursorId_void, ZEND_ACC_PRIVATE | ZEND_ACC_FINAL)
+	ZEND_NAMED_ME(__wakeup, PHP_FN(MongoDB_disabled___wakeup), ai_CursorId_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
 	PHP_FE_END
+	/* clang-format on */
 };
 /* }}} */
 
 /* {{{ MongoDB\Driver\CursorId object handlers */
 static zend_object_handlers php_phongo_handler_cursorid;
 
-static void php_phongo_cursorid_free_object(phongo_free_object_arg *object TSRMLS_DC) /* {{{ */
+static void php_phongo_cursorid_free_object(phongo_free_object_arg* object TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursorid_t *intern = Z_OBJ_CURSORID(object);
+	php_phongo_cursorid_t* intern = Z_OBJ_CURSORID(object);
 
 	zend_object_std_dtor(&intern->std TSRMLS_CC);
 
@@ -72,9 +75,9 @@ static void php_phongo_cursorid_free_object(phongo_free_object_arg *object TSRML
 #endif
 } /* }}} */
 
-static phongo_create_object_retval php_phongo_cursorid_create_object(zend_class_entry *class_type TSRMLS_DC) /* {{{ */
+static phongo_create_object_retval php_phongo_cursorid_create_object(zend_class_entry* class_type TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursorid_t *intern = NULL;
+	php_phongo_cursorid_t* intern = NULL;
 
 	intern = PHONGO_ALLOC_OBJECT_T(php_phongo_cursorid_t, class_type);
 
@@ -88,7 +91,7 @@ static phongo_create_object_retval php_phongo_cursorid_create_object(zend_class_
 #else
 	{
 		zend_object_value retval;
-		retval.handle = zend_objects_store_put(intern, (zend_objects_store_dtor_t) zend_objects_destroy_object, php_phongo_cursorid_free_object, NULL TSRMLS_CC);
+		retval.handle   = zend_objects_store_put(intern, (zend_objects_store_dtor_t) zend_objects_destroy_object, php_phongo_cursorid_free_object, NULL TSRMLS_CC);
 		retval.handlers = &php_phongo_handler_cursorid;
 
 		return retval;
@@ -96,25 +99,20 @@ static phongo_create_object_retval php_phongo_cursorid_create_object(zend_class_
 #endif
 } /* }}} */
 
-static HashTable *php_phongo_cursorid_get_debug_info(zval *object, int *is_temp TSRMLS_DC) /* {{{ */
+static HashTable* php_phongo_cursorid_get_debug_info(zval* object, int* is_temp TSRMLS_DC) /* {{{ */
 {
-	php_phongo_cursorid_t  *intern;
-#if PHP_VERSION_ID >= 70000
-	zval                    retval;
-#else
-	zval                    retval = zval_used_for_init;
-#endif
-
+	php_phongo_cursorid_t* intern;
+	zval                   retval = ZVAL_STATIC_INIT;
 
 	*is_temp = 1;
-	intern = Z_CURSORID_OBJ_P(object);
+	intern   = Z_CURSORID_OBJ_P(object);
 
 	array_init(&retval);
 
 #if SIZEOF_LONG == 4
 	{
 		char tmp[24];
-		int tmp_len;
+		int  tmp_len;
 
 		tmp_len = snprintf(tmp, sizeof(tmp), "%" PRId64, intern->id);
 		ADD_ASSOC_STRINGL(&retval, "id", tmp, tmp_len);
@@ -132,7 +130,7 @@ void php_phongo_cursorid_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	zend_class_entry ce;
 
 	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\Driver", "CursorId", php_phongo_cursorid_me);
-	php_phongo_cursorid_ce = zend_register_internal_class(&ce TSRMLS_CC);
+	php_phongo_cursorid_ce                = zend_register_internal_class(&ce TSRMLS_CC);
 	php_phongo_cursorid_ce->create_object = php_phongo_cursorid_create_object;
 	PHONGO_CE_FINAL(php_phongo_cursorid_ce);
 	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_cursorid_ce);
@@ -141,7 +139,7 @@ void php_phongo_cursorid_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	php_phongo_handler_cursorid.get_debug_info = php_phongo_cursorid_get_debug_info;
 #if PHP_VERSION_ID >= 70000
 	php_phongo_handler_cursorid.free_obj = php_phongo_cursorid_free_object;
-	php_phongo_handler_cursorid.offset = XtOffsetOf(php_phongo_cursorid_t, std);
+	php_phongo_handler_cursorid.offset   = XtOffsetOf(php_phongo_cursorid_t, std);
 #endif
 } /* }}} */
 
