@@ -15,7 +15,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 #include <php.h>
@@ -23,7 +23,7 @@
 #include "phongo_compat.h"
 #include "php_phongo.h"
 
-zend_class_entry *php_phongo_executiontimeoutexception_ce;
+zend_class_entry* php_phongo_executiontimeoutexception_ce;
 
 /* {{{ MongoDB\Driver\Exception\ExecutionTimeoutException function entries */
 static zend_function_entry php_phongo_executiontimeoutexception_me[] = {
@@ -37,9 +37,9 @@ void php_phongo_executiontimeoutexception_init_ce(INIT_FUNC_ARGS) /* {{{ */
 
 	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\Driver\\Exception", "ExecutionTimeoutException", php_phongo_executiontimeoutexception_me);
 #if PHP_VERSION_ID >= 70000
-	php_phongo_executiontimeoutexception_ce = zend_register_internal_class_ex(&ce, php_phongo_runtimeexception_ce);
+	php_phongo_executiontimeoutexception_ce = zend_register_internal_class_ex(&ce, php_phongo_serverexception_ce);
 #else
-	php_phongo_executiontimeoutexception_ce = zend_register_internal_class_ex(&ce, php_phongo_runtimeexception_ce, NULL TSRMLS_CC);
+	php_phongo_executiontimeoutexception_ce = zend_register_internal_class_ex(&ce, php_phongo_serverexception_ce, NULL TSRMLS_CC);
 #endif
 	PHONGO_CE_FINAL(php_phongo_executiontimeoutexception_ce);
 } /* }}} */
