@@ -15,7 +15,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 #include <php.h>
@@ -24,15 +24,16 @@
 #include "phongo_compat.h"
 #include "php_phongo.h"
 
-zend_class_entry *php_phongo_commandstartedevent_ce;
+zend_class_entry* php_phongo_commandstartedevent_ce;
 
 /* {{{ proto stdClass CommandStartedEvent::getCommand()
    Returns the command document associated with the event */
 PHP_METHOD(CommandStartedEvent, getCommand)
 {
-	php_phongo_commandstartedevent_t *intern;
-	php_phongo_bson_state state = PHONGO_BSON_STATE_INITIALIZER;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandstartedevent_t* intern;
+	php_phongo_bson_state             state = PHONGO_BSON_STATE_INITIALIZER;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSTARTEDEVENT_OBJ_P(getThis());
 
@@ -52,8 +53,9 @@ PHP_METHOD(CommandStartedEvent, getCommand)
    Returns the command name for this event */
 PHP_METHOD(CommandStartedEvent, getCommandName)
 {
-	php_phongo_commandstartedevent_t *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandstartedevent_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSTARTEDEVENT_OBJ_P(getThis());
 
@@ -68,8 +70,9 @@ PHP_METHOD(CommandStartedEvent, getCommandName)
    Returns the database name for this event */
 PHP_METHOD(CommandStartedEvent, getDatabaseName)
 {
-	php_phongo_commandstartedevent_t *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandstartedevent_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSTARTEDEVENT_OBJ_P(getThis());
 
@@ -84,9 +87,10 @@ PHP_METHOD(CommandStartedEvent, getDatabaseName)
    Returns the event's operation ID */
 PHP_METHOD(CommandStartedEvent, getOperationId)
 {
-	php_phongo_commandstartedevent_t *intern;
-	char int_as_string[20];
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandstartedevent_t* intern;
+	char                              int_as_string[20];
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSTARTEDEVENT_OBJ_P(getThis());
 
@@ -94,7 +98,7 @@ PHP_METHOD(CommandStartedEvent, getOperationId)
 		return;
 	}
 
-	sprintf(int_as_string, "%" PHONGO_LONG_FORMAT, intern->operation_id);
+	sprintf(int_as_string, "%" PRIu64, intern->operation_id);
 	PHONGO_RETVAL_STRING(int_as_string);
 } /* }}} */
 
@@ -102,9 +106,10 @@ PHP_METHOD(CommandStartedEvent, getOperationId)
    Returns the event's request ID */
 PHP_METHOD(CommandStartedEvent, getRequestId)
 {
-	php_phongo_commandstartedevent_t *intern;
-	char int_as_string[20];
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandstartedevent_t* intern;
+	char                              int_as_string[20];
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSTARTEDEVENT_OBJ_P(getThis());
 
@@ -112,7 +117,7 @@ PHP_METHOD(CommandStartedEvent, getRequestId)
 		return;
 	}
 
-	sprintf(int_as_string, "%" PHONGO_LONG_FORMAT, intern->request_id);
+	sprintf(int_as_string, "%" PRIu64, intern->request_id);
 	PHONGO_RETVAL_STRING(int_as_string);
 } /* }}} */
 
@@ -120,8 +125,9 @@ PHP_METHOD(CommandStartedEvent, getRequestId)
    Returns the Server from which the event originated */
 PHP_METHOD(CommandStartedEvent, getServer)
 {
-	php_phongo_commandstartedevent_t *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandstartedevent_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSTARTEDEVENT_OBJ_P(getThis());
 
@@ -143,24 +149,26 @@ ZEND_BEGIN_ARG_INFO_EX(ai_CommandStartedEvent_void, 0, 0, 0)
 ZEND_END_ARG_INFO()
 
 static zend_function_entry php_phongo_commandstartedevent_me[] = {
-	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_CommandStartedEvent_void, ZEND_ACC_PRIVATE|ZEND_ACC_FINAL)
-	PHP_ME(CommandStartedEvent, getCommand, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(CommandStartedEvent, getCommandName, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(CommandStartedEvent, getDatabaseName, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(CommandStartedEvent, getOperationId, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(CommandStartedEvent, getRequestId, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(CommandStartedEvent, getServer, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	ZEND_NAMED_ME(__wakeup, PHP_FN(MongoDB_disabled___wakeup), ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
+	/* clang-format off */
+	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_CommandStartedEvent_void, ZEND_ACC_PRIVATE | ZEND_ACC_FINAL)
+	PHP_ME(CommandStartedEvent, getCommand, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(CommandStartedEvent, getCommandName, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(CommandStartedEvent, getDatabaseName, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(CommandStartedEvent, getOperationId, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(CommandStartedEvent, getRequestId, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(CommandStartedEvent, getServer, ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	ZEND_NAMED_ME(__wakeup, PHP_FN(MongoDB_disabled___wakeup), ai_CommandStartedEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
 	PHP_FE_END
+	/* clang-format on */
 };
 /* }}} */
 
 /* {{{ MongoDB\Driver\Monitoring\CommandStartedEvent object handlers */
 static zend_object_handlers php_phongo_handler_commandstartedevent;
 
-static void php_phongo_commandstartedevent_free_object(phongo_free_object_arg *object TSRMLS_DC) /* {{{ */
+static void php_phongo_commandstartedevent_free_object(phongo_free_object_arg* object TSRMLS_DC) /* {{{ */
 {
-	php_phongo_commandstartedevent_t *intern = Z_OBJ_COMMANDSTARTEDEVENT(object);
+	php_phongo_commandstartedevent_t* intern = Z_OBJ_COMMANDSTARTEDEVENT(object);
 
 	zend_object_std_dtor(&intern->std TSRMLS_CC);
 
@@ -179,9 +187,9 @@ static void php_phongo_commandstartedevent_free_object(phongo_free_object_arg *o
 #endif
 } /* }}} */
 
-static phongo_create_object_retval php_phongo_commandstartedevent_create_object(zend_class_entry *class_type TSRMLS_DC) /* {{{ */
+static phongo_create_object_retval php_phongo_commandstartedevent_create_object(zend_class_entry* class_type TSRMLS_DC) /* {{{ */
 {
-	php_phongo_commandstartedevent_t *intern = NULL;
+	php_phongo_commandstartedevent_t* intern = NULL;
 
 	intern = PHONGO_ALLOC_OBJECT_T(php_phongo_commandstartedevent_t, class_type);
 
@@ -195,7 +203,7 @@ static phongo_create_object_retval php_phongo_commandstartedevent_create_object(
 #else
 	{
 		zend_object_value retval;
-		retval.handle = zend_objects_store_put(intern, (zend_objects_store_dtor_t) zend_objects_destroy_object, php_phongo_commandstartedevent_free_object, NULL TSRMLS_CC);
+		retval.handle   = zend_objects_store_put(intern, (zend_objects_store_dtor_t) zend_objects_destroy_object, php_phongo_commandstartedevent_free_object, NULL TSRMLS_CC);
 		retval.handlers = &php_phongo_handler_commandstartedevent;
 
 		return retval;
@@ -203,18 +211,14 @@ static phongo_create_object_retval php_phongo_commandstartedevent_create_object(
 #endif
 } /* }}} */
 
-static HashTable *php_phongo_commandstartedevent_get_debug_info(zval *object, int *is_temp TSRMLS_DC) /* {{{ */
+static HashTable* php_phongo_commandstartedevent_get_debug_info(zval* object, int* is_temp TSRMLS_DC) /* {{{ */
 {
-	php_phongo_commandstartedevent_t *intern;
-#if PHP_VERSION_ID >= 70000
-	zval                      retval;
-#else
-	zval                      retval = zval_used_for_init;
-#endif
-	char operation_id[20], request_id[20];
-	php_phongo_bson_state command_state = PHONGO_BSON_STATE_INITIALIZER;
+	php_phongo_commandstartedevent_t* intern;
+	zval                              retval = ZVAL_STATIC_INIT;
+	char                              operation_id[20], request_id[20];
+	php_phongo_bson_state             command_state = PHONGO_BSON_STATE_INITIALIZER;
 
-	intern = Z_COMMANDSTARTEDEVENT_OBJ_P(object);
+	intern   = Z_COMMANDSTARTEDEVENT_OBJ_P(object);
 	*is_temp = 1;
 	array_init_size(&retval, 6);
 
@@ -228,10 +232,10 @@ static HashTable *php_phongo_commandstartedevent_get_debug_info(zval *object, in
 	ADD_ASSOC_STRING(&retval, "commandName", intern->command_name);
 	ADD_ASSOC_STRING(&retval, "databaseName", intern->database_name);
 
-	sprintf(operation_id, "%" PHONGO_LONG_FORMAT, intern->operation_id);
+	sprintf(operation_id, "%" PRIu64, intern->operation_id);
 	ADD_ASSOC_STRING(&retval, "operationId", operation_id);
 
-	sprintf(request_id, "%" PHONGO_LONG_FORMAT, intern->request_id);
+	sprintf(request_id, "%" PRIu64, intern->request_id);
 	ADD_ASSOC_STRING(&retval, "requestId", request_id);
 
 	{
@@ -241,7 +245,7 @@ static HashTable *php_phongo_commandstartedevent_get_debug_info(zval *object, in
 		phongo_server_init(&server, intern->client, intern->server_id TSRMLS_CC);
 		ADD_ASSOC_ZVAL_EX(&retval, "server", &server);
 #else
-		zval *server = NULL;
+		zval* server = NULL;
 
 		MAKE_STD_ZVAL(server);
 		phongo_server_init(server, intern->client, intern->server_id TSRMLS_CC);
@@ -256,10 +260,11 @@ static HashTable *php_phongo_commandstartedevent_get_debug_info(zval *object, in
 void php_phongo_commandstartedevent_init_ce(INIT_FUNC_ARGS) /* {{{ */
 {
 	zend_class_entry ce;
-	(void)type;(void)module_number;
+	(void) type;
+	(void) module_number;
 
 	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\Driver\\Monitoring", "CommandStartedEvent", php_phongo_commandstartedevent_me);
-	php_phongo_commandstartedevent_ce = zend_register_internal_class(&ce TSRMLS_CC);
+	php_phongo_commandstartedevent_ce                = zend_register_internal_class(&ce TSRMLS_CC);
 	php_phongo_commandstartedevent_ce->create_object = php_phongo_commandstartedevent_create_object;
 	PHONGO_CE_FINAL(php_phongo_commandstartedevent_ce);
 	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_commandstartedevent_ce);
@@ -268,7 +273,7 @@ void php_phongo_commandstartedevent_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	php_phongo_handler_commandstartedevent.get_debug_info = php_phongo_commandstartedevent_get_debug_info;
 #if PHP_VERSION_ID >= 70000
 	php_phongo_handler_commandstartedevent.free_obj = php_phongo_commandstartedevent_free_object;
-	php_phongo_handler_commandstartedevent.offset = XtOffsetOf(php_phongo_commandstartedevent_t, std);
+	php_phongo_handler_commandstartedevent.offset   = XtOffsetOf(php_phongo_commandstartedevent_t, std);
 #endif
 
 	return;
