@@ -15,7 +15,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 #include <php.h>
@@ -24,14 +24,15 @@
 #include "phongo_compat.h"
 #include "php_phongo.h"
 
-zend_class_entry *php_phongo_commandsucceededevent_ce;
+zend_class_entry* php_phongo_commandsucceededevent_ce;
 
 /* {{{ proto string CommandSucceededEvent::getCommandName()
    Returns the command name for this event */
 PHP_METHOD(CommandSucceededEvent, getCommandName)
 {
-	php_phongo_commandsucceededevent_t *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandsucceededevent_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSUCCEEDEDEVENT_OBJ_P(getThis());
 
@@ -46,8 +47,9 @@ PHP_METHOD(CommandSucceededEvent, getCommandName)
    Returns the event's duration in microseconds */
 PHP_METHOD(CommandSucceededEvent, getDurationMicros)
 {
-	php_phongo_commandsucceededevent_t *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandsucceededevent_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSUCCEEDEDEVENT_OBJ_P(getThis());
 
@@ -62,9 +64,10 @@ PHP_METHOD(CommandSucceededEvent, getDurationMicros)
    Returns the event's operation ID */
 PHP_METHOD(CommandSucceededEvent, getOperationId)
 {
-	php_phongo_commandsucceededevent_t *intern;
-	char int_as_string[20];
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandsucceededevent_t* intern;
+	char                                int_as_string[20];
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSUCCEEDEDEVENT_OBJ_P(getThis());
 
@@ -72,7 +75,7 @@ PHP_METHOD(CommandSucceededEvent, getOperationId)
 		return;
 	}
 
-	sprintf(int_as_string, "%" PHONGO_LONG_FORMAT, intern->operation_id);
+	sprintf(int_as_string, "%" PRIu64, intern->operation_id);
 	PHONGO_RETVAL_STRING(int_as_string);
 } /* }}} */
 
@@ -80,9 +83,10 @@ PHP_METHOD(CommandSucceededEvent, getOperationId)
    Returns the reply document associated with the event */
 PHP_METHOD(CommandSucceededEvent, getReply)
 {
-	php_phongo_commandsucceededevent_t *intern;
-	php_phongo_bson_state state = PHONGO_BSON_STATE_INITIALIZER;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandsucceededevent_t* intern;
+	php_phongo_bson_state               state = PHONGO_BSON_STATE_INITIALIZER;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSUCCEEDEDEVENT_OBJ_P(getThis());
 
@@ -102,9 +106,10 @@ PHP_METHOD(CommandSucceededEvent, getReply)
    Returns the event's request ID */
 PHP_METHOD(CommandSucceededEvent, getRequestId)
 {
-	php_phongo_commandsucceededevent_t *intern;
-	char int_as_string[20];
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandsucceededevent_t* intern;
+	char                                int_as_string[20];
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSUCCEEDEDEVENT_OBJ_P(getThis());
 
@@ -112,7 +117,7 @@ PHP_METHOD(CommandSucceededEvent, getRequestId)
 		return;
 	}
 
-	sprintf(int_as_string, "%" PHONGO_LONG_FORMAT, intern->request_id);
+	sprintf(int_as_string, "%" PRIu64, intern->request_id);
 	PHONGO_RETVAL_STRING(int_as_string);
 } /* }}} */
 
@@ -120,8 +125,9 @@ PHP_METHOD(CommandSucceededEvent, getRequestId)
    Returns the Server from which the event originated */
 PHP_METHOD(CommandSucceededEvent, getServer)
 {
-	php_phongo_commandsucceededevent_t *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_commandsucceededevent_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_COMMANDSUCCEEDEDEVENT_OBJ_P(getThis());
 
@@ -143,24 +149,26 @@ ZEND_BEGIN_ARG_INFO_EX(ai_CommandSucceededEvent_void, 0, 0, 0)
 ZEND_END_ARG_INFO()
 
 static zend_function_entry php_phongo_commandsucceededevent_me[] = {
-	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_CommandSucceededEvent_void, ZEND_ACC_PRIVATE|ZEND_ACC_FINAL)
-	PHP_ME(CommandSucceededEvent, getCommandName, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(CommandSucceededEvent, getDurationMicros, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(CommandSucceededEvent, getOperationId, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(CommandSucceededEvent, getReply, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(CommandSucceededEvent, getRequestId, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(CommandSucceededEvent, getServer, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	ZEND_NAMED_ME(__wakeup, PHP_FN(MongoDB_disabled___wakeup), ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
+	/* clang-format off */
+	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_CommandSucceededEvent_void, ZEND_ACC_PRIVATE | ZEND_ACC_FINAL)
+	PHP_ME(CommandSucceededEvent, getCommandName, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(CommandSucceededEvent, getDurationMicros, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(CommandSucceededEvent, getOperationId, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(CommandSucceededEvent, getReply, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(CommandSucceededEvent, getRequestId, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(CommandSucceededEvent, getServer, ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	ZEND_NAMED_ME(__wakeup, PHP_FN(MongoDB_disabled___wakeup), ai_CommandSucceededEvent_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
 	PHP_FE_END
+	/* clang-format on */
 };
 /* }}} */
 
 /* {{{ MongoDB\Driver\Monitoring\CommandSucceededEvent object handlers */
 static zend_object_handlers php_phongo_handler_commandsucceededevent;
 
-static void php_phongo_commandsucceededevent_free_object(phongo_free_object_arg *object TSRMLS_DC) /* {{{ */
+static void php_phongo_commandsucceededevent_free_object(phongo_free_object_arg* object TSRMLS_DC) /* {{{ */
 {
-	php_phongo_commandsucceededevent_t *intern = Z_OBJ_COMMANDSUCCEEDEDEVENT(object);
+	php_phongo_commandsucceededevent_t* intern = Z_OBJ_COMMANDSUCCEEDEDEVENT(object);
 
 	zend_object_std_dtor(&intern->std TSRMLS_CC);
 
@@ -176,9 +184,9 @@ static void php_phongo_commandsucceededevent_free_object(phongo_free_object_arg
 #endif
 } /* }}} */
 
-static phongo_create_object_retval php_phongo_commandsucceededevent_create_object(zend_class_entry *class_type TSRMLS_DC) /* {{{ */
+static phongo_create_object_retval php_phongo_commandsucceededevent_create_object(zend_class_entry* class_type TSRMLS_DC) /* {{{ */
 {
-	php_phongo_commandsucceededevent_t *intern = NULL;
+	php_phongo_commandsucceededevent_t* intern = NULL;
 
 	intern = PHONGO_ALLOC_OBJECT_T(php_phongo_commandsucceededevent_t, class_type);
 
@@ -192,7 +200,7 @@ static phongo_create_object_retval php_phongo_commandsucceededevent_create_objec
 #else
 	{
 		zend_object_value retval;
-		retval.handle = zend_objects_store_put(intern, (zend_objects_store_dtor_t) zend_objects_destroy_object, php_phongo_commandsucceededevent_free_object, NULL TSRMLS_CC);
+		retval.handle   = zend_objects_store_put(intern, (zend_objects_store_dtor_t) zend_objects_destroy_object, php_phongo_commandsucceededevent_free_object, NULL TSRMLS_CC);
 		retval.handlers = &php_phongo_handler_commandsucceededevent;
 
 		return retval;
@@ -200,25 +208,21 @@ static phongo_create_object_retval php_phongo_commandsucceededevent_create_objec
 #endif
 } /* }}} */
 
-static HashTable *php_phongo_commandsucceededevent_get_debug_info(zval *object, int *is_temp TSRMLS_DC) /* {{{ */
+static HashTable* php_phongo_commandsucceededevent_get_debug_info(zval* object, int* is_temp TSRMLS_DC) /* {{{ */
 {
-	php_phongo_commandsucceededevent_t *intern;
-#if PHP_VERSION_ID >= 70000
-	zval                      retval;
-#else
-	zval                      retval = zval_used_for_init;
-#endif
-	char operation_id[20], request_id[20];
-	php_phongo_bson_state reply_state = PHONGO_BSON_STATE_INITIALIZER;
+	php_phongo_commandsucceededevent_t* intern;
+	zval                                retval = ZVAL_STATIC_INIT;
+	char                                operation_id[20], request_id[20];
+	php_phongo_bson_state               reply_state = PHONGO_BSON_STATE_INITIALIZER;
 
-	intern = Z_COMMANDSUCCEEDEDEVENT_OBJ_P(object);
+	intern   = Z_COMMANDSUCCEEDEDEVENT_OBJ_P(object);
 	*is_temp = 1;
 	array_init_size(&retval, 6);
 
 	ADD_ASSOC_STRING(&retval, "commandName", intern->command_name);
-	ADD_ASSOC_INT64(&retval, "durationMicros", intern->duration_micros);
+	ADD_ASSOC_INT64(&retval, "durationMicros", (int64_t) intern->duration_micros);
 
-	sprintf(operation_id, "%" PHONGO_LONG_FORMAT, intern->operation_id);
+	sprintf(operation_id, "%" PRIu64, intern->operation_id);
 	ADD_ASSOC_STRING(&retval, "operationId", operation_id);
 
 	php_phongo_bson_to_zval_ex(bson_get_data(intern->reply), intern->reply->len, &reply_state);
@@ -228,7 +232,7 @@ static HashTable *php_phongo_commandsucceededevent_get_debug_info(zval *object,
 	ADD_ASSOC_ZVAL(&retval, "reply", reply_state.zchild);
 #endif
 
-	sprintf(request_id, "%" PHONGO_LONG_FORMAT, intern->request_id);
+	sprintf(request_id, "%" PRIu64, intern->request_id);
 	ADD_ASSOC_STRING(&retval, "requestId", request_id);
 
 	{
@@ -238,7 +242,7 @@ static HashTable *php_phongo_commandsucceededevent_get_debug_info(zval *object,
 		phongo_server_init(&server, intern->client, intern->server_id TSRMLS_CC);
 		ADD_ASSOC_ZVAL_EX(&retval, "server", &server);
 #else
-		zval *server = NULL;
+		zval* server = NULL;
 
 		MAKE_STD_ZVAL(server);
 		phongo_server_init(server, intern->client, intern->server_id TSRMLS_CC);
@@ -253,10 +257,11 @@ static HashTable *php_phongo_commandsucceededevent_get_debug_info(zval *object,
 void php_phongo_commandsucceededevent_init_ce(INIT_FUNC_ARGS) /* {{{ */
 {
 	zend_class_entry ce;
-	(void)type;(void)module_number;
+	(void) type;
+	(void) module_number;
 
 	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\Driver\\Monitoring", "CommandSucceededEvent", php_phongo_commandsucceededevent_me);
-	php_phongo_commandsucceededevent_ce = zend_register_internal_class(&ce TSRMLS_CC);
+	php_phongo_commandsucceededevent_ce                = zend_register_internal_class(&ce TSRMLS_CC);
 	php_phongo_commandsucceededevent_ce->create_object = php_phongo_commandsucceededevent_create_object;
 	PHONGO_CE_FINAL(php_phongo_commandsucceededevent_ce);
 	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_commandsucceededevent_ce);
@@ -265,7 +270,7 @@ void php_phongo_commandsucceededevent_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	php_phongo_handler_commandsucceededevent.get_debug_info = php_phongo_commandsucceededevent_get_debug_info;
 #if PHP_VERSION_ID >= 70000
 	php_phongo_handler_commandsucceededevent.free_obj = php_phongo_commandsucceededevent_free_object;
-	php_phongo_handler_commandsucceededevent.offset = XtOffsetOf(php_phongo_commandsucceededevent_t, std);
+	php_phongo_handler_commandsucceededevent.offset   = XtOffsetOf(php_phongo_commandsucceededevent_t, std);
 #endif
 
 	return;
