@@ -15,7 +15,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#	include "config.h"
+#include "config.h"
 #endif
 
 #include <php.h>
@@ -24,7 +24,7 @@
 #include "phongo_compat.h"
 #include "php_phongo.h"
 
-zend_class_entry *php_phongo_subscriber_ce;
+zend_class_entry* php_phongo_subscriber_ce;
 
 /* {{{ MongoDB\Driver\Monitoring\Subscriber function entries */
 static zend_function_entry php_phongo_subscriber_me[] = {
@@ -35,7 +35,8 @@ static zend_function_entry php_phongo_subscriber_me[] = {
 void php_phongo_subscriber_init_ce(INIT_FUNC_ARGS) /* {{{ */
 {
 	zend_class_entry ce;
-	(void)type;(void)module_number;
+	(void) type;
+	(void) module_number;
 
 	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\Driver\\Monitoring", "Subscriber", php_phongo_subscriber_me);
 	php_phongo_subscriber_ce = zend_register_internal_interface(&ce TSRMLS_CC);
