@@ -15,7 +15,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 #include <php.h>
@@ -26,19 +26,20 @@
 #include "php_phongo.h"
 #include "php_bson.h"
 
-zend_class_entry *php_phongo_readpreference_ce;
+zend_class_entry* php_phongo_readpreference_ce;
 
 /* {{{ proto void MongoDB\Driver\ReadPreference::__construct(int|string $mode[, array $tagSets = array()[, array $options = array()]])
    Constructs a new ReadPreference */
 static PHP_METHOD(ReadPreference, __construct)
 {
-	php_phongo_readpreference_t *intern;
-	zend_error_handling       error_handling;
-	zval                     *mode;
-	zval                     *tagSets = NULL;
-	zval                     *options = NULL;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value) SUPPRESS_UNUSED_WARNING(return_value_used)
-
+	php_phongo_readpreference_t* intern;
+	zend_error_handling          error_handling;
+	zval*                        mode;
+	zval*                        tagSets = NULL;
+	zval*                        options = NULL;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	zend_replace_error_handling(EH_THROW, phongo_exception_from_phongo_domain(PHONGO_ERROR_INVALID_ARGUMENT), &error_handling TSRMLS_CC);
 	intern = Z_READPREFERENCE_OBJ_P(getThis());
@@ -52,7 +53,7 @@ static PHP_METHOD(ReadPreference, __construct)
 	zend_restore_error_handling(&error_handling TSRMLS_CC);
 
 	if (Z_TYPE_P(mode) == IS_LONG) {
-		switch(Z_LVAL_P(mode)) {
+		switch (Z_LVAL_P(mode)) {
 			case MONGOC_READ_PRIMARY:
 			case MONGOC_READ_SECONDARY:
 			case MONGOC_READ_PRIMARY_PREFERRED:
@@ -80,15 +81,15 @@ static PHP_METHOD(ReadPreference, __construct)
 			return;
 		}
 	} else {
-		phongo_throw_exception(PHONGO_ERROR_INVALID_ARGUMENT TSRMLS_CC, "Expected mode to be integer or string, %s given", zend_get_type_by_const(Z_TYPE_P(mode)));
+		phongo_throw_exception(PHONGO_ERROR_INVALID_ARGUMENT TSRMLS_CC, "Expected mode to be integer or string, %s given", PHONGO_ZVAL_CLASS_OR_TYPE_NAME_P(mode));
 		return;
 	}
 
 	if (tagSets) {
-		bson_t *tags = bson_new();
+		bson_t* tags = bson_new();
 
 		php_phongo_read_preference_prep_tagsets(tagSets TSRMLS_CC);
-		php_phongo_zval_to_bson(tagSets, PHONGO_BSON_NONE, (bson_t *)tags, NULL TSRMLS_CC);
+		php_phongo_zval_to_bson(tagSets, PHONGO_BSON_NONE, (bson_t*) tags, NULL TSRMLS_CC);
 
 		if (!php_phongo_read_preference_tags_are_valid(tags)) {
 			phongo_throw_exception(PHONGO_ERROR_INVALID_ARGUMENT TSRMLS_CC, "tagSets must be an array of zero or more documents");
@@ -137,8 +138,9 @@ static PHP_METHOD(ReadPreference, __construct)
    Returns the ReadPreference maxStalenessSeconds value */
 static PHP_METHOD(ReadPreference, getMaxStalenessSeconds)
 {
-	php_phongo_readpreference_t *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_readpreference_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_READPREFERENCE_OBJ_P(getThis());
 
@@ -153,8 +155,9 @@ static PHP_METHOD(ReadPreference, getMaxStalenessSeconds)
    Returns the ReadPreference mode */
 static PHP_METHOD(ReadPreference, getMode)
 {
-	php_phongo_readpreference_t *intern;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_readpreference_t* intern;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_READPREFERENCE_OBJ_P(getThis());
 
@@ -169,9 +172,10 @@ static PHP_METHOD(ReadPreference, getMode)
    Returns the ReadPreference tag sets */
 static PHP_METHOD(ReadPreference, getTagSets)
 {
-	php_phongo_readpreference_t *intern;
-	const bson_t                *tags;
-	SUPPRESS_UNUSED_WARNING(return_value_ptr) SUPPRESS_UNUSED_WARNING(return_value_used)
+	php_phongo_readpreference_t* intern;
+	const bson_t*                tags;
+	SUPPRESS_UNUSED_WARNING(return_value_ptr)
+	SUPPRESS_UNUSED_WARNING(return_value_used)
 
 	intern = Z_READPREFERENCE_OBJ_P(getThis());
 
@@ -184,7 +188,7 @@ static PHP_METHOD(ReadPreference, getTagSets)
 	if (tags->len) {
 		php_phongo_bson_state state = PHONGO_BSON_STATE_INITIALIZER;
 		/* Use native arrays for debugging output */
-		state.map.root_type = PHONGO_TYPEMAP_NATIVE_ARRAY;
+		state.map.root_type     = PHONGO_TYPEMAP_NATIVE_ARRAY;
 		state.map.document_type = PHONGO_TYPEMAP_NATIVE_ARRAY;
 
 		php_phongo_bson_to_zval_ex(bson_get_data(tags), tags->len, &state);
@@ -198,17 +202,105 @@ static PHP_METHOD(ReadPreference, getTagSets)
 	}
 } /* }}} */
 
+static HashTable* php_phongo_readpreference_get_properties_hash(zval* object, bool is_debug TSRMLS_DC) /* {{{ */
+{
+	php_phongo_readpreference_t* intern;
+	HashTable*                   props;
+	const char*                  modeString = NULL;
+	const bson_t*                tags;
+	mongoc_read_mode_t           mode;
+
+	intern = Z_READPREFERENCE_OBJ_P(object);
+
+	PHONGO_GET_PROPERTY_HASH_INIT_PROPS(is_debug, intern, props, 3);
+
+	if (!intern->read_preference) {
+		return props;
+	}
+
+	tags = mongoc_read_prefs_get_tags(intern->read_preference);
+	mode = mongoc_read_prefs_get_mode(intern->read_preference);
+
+	switch (mode) {
+		case MONGOC_READ_PRIMARY:
+			modeString = "primary";
+			break;
+		case MONGOC_READ_PRIMARY_PREFERRED:
+			modeString = "primaryPreferred";
+			break;
+		case MONGOC_READ_SECONDARY:
+			modeString = "secondary";
+			break;
+		case MONGOC_READ_SECONDARY_PREFERRED:
+			modeString = "secondaryPreferred";
+			break;
+		case MONGOC_READ_NEAREST:
+			modeString = "nearest";
+			break;
+		default: /* Do nothing */
+			break;
+	}
+
+	if (modeString) {
+#if PHP_VERSION_ID >= 70000
+		zval z_mode;
+
+		ZVAL_STRING(&z_mode, modeString);
+		zend_hash_str_update(props, "mode", sizeof("mode") - 1, &z_mode);
+#else
+		zval* z_mode;
+
+		MAKE_STD_ZVAL(z_mode);
+		ZVAL_STRING(z_mode, modeString, 1);
+		zend_hash_update(props, "mode", sizeof("mode"), &z_mode, sizeof(z_mode), NULL);
+#endif
+	}
+
+	if (!bson_empty0(tags)) {
+		/* Use PHONGO_TYPEMAP_NATIVE_ARRAY for the root type since tags is an
+		 * array; however, inner documents and arrays can use the default. */
+		php_phongo_bson_state state = PHONGO_BSON_STATE_INITIALIZER;
+		state.map.root_type         = PHONGO_TYPEMAP_NATIVE_ARRAY;
+
+		php_phongo_bson_to_zval_ex(bson_get_data(tags), tags->len, &state);
+#if PHP_VERSION_ID >= 70000
+		Z_ADDREF(state.zchild);
+		zend_hash_str_update(props, "tags", sizeof("tags") - 1, &state.zchild);
+#else
+		Z_ADDREF_P(state.zchild);
+		zend_hash_update(props, "tags", sizeof("tags"), &state.zchild, sizeof(state.zchild), NULL);
+#endif
+		zval_ptr_dtor(&state.zchild);
+	}
+
+	if (mongoc_read_prefs_get_max_staleness_seconds(intern->read_preference) != MONGOC_NO_MAX_STALENESS) {
+		long maxStalenessSeconds = mongoc_read_prefs_get_max_staleness_seconds(intern->read_preference);
+#if PHP_VERSION_ID >= 70000
+		zval z_max_ss;
+
+		ZVAL_LONG(&z_max_ss, maxStalenessSeconds);
+		zend_hash_str_update(props, "maxStalenessSeconds", sizeof("maxStalenessSeconds") - 1, &z_max_ss);
+#else
+		zval* z_max_ss;
+
+		MAKE_STD_ZVAL(z_max_ss);
+		ZVAL_LONG(z_max_ss, maxStalenessSeconds);
+		zend_hash_update(props, "maxStalenessSeconds", sizeof("maxStalenessSeconds"), &z_max_ss, sizeof(z_max_ss), NULL);
+#endif
+	}
+
+	return props;
+} /* }}} */
+
 /* {{{ proto array MongoDB\Driver\ReadPreference::bsonSerialize()
 */
 static PHP_METHOD(ReadPreference, bsonSerialize)
 {
-	const mongoc_read_prefs_t *read_preference = phongo_read_preference_from_zval(getThis() TSRMLS_CC);
-
 	if (zend_parse_parameters_none() == FAILURE) {
 		return;
 	}
 
-	php_phongo_read_preference_to_zval(return_value, read_preference);
+	ZVAL_ARR(return_value, php_phongo_readpreference_get_properties_hash(getThis(), true TSRMLS_CC));
 	convert_to_object(return_value);
 } /* }}} */
 
@@ -223,24 +315,31 @@ ZEND_BEGIN_ARG_INFO_EX(ai_ReadPreference_void, 0, 0, 0)
 ZEND_END_ARG_INFO()
 
 static zend_function_entry php_phongo_readpreference_me[] = {
-	PHP_ME(ReadPreference, __construct, ai_ReadPreference___construct, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(ReadPreference, getMaxStalenessSeconds, ai_ReadPreference_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(ReadPreference, getMode, ai_ReadPreference_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(ReadPreference, getTagSets, ai_ReadPreference_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(ReadPreference, bsonSerialize, ai_ReadPreference_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
+	/* clang-format off */
+	PHP_ME(ReadPreference, __construct, ai_ReadPreference___construct, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(ReadPreference, getMaxStalenessSeconds, ai_ReadPreference_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(ReadPreference, getMode, ai_ReadPreference_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(ReadPreference, getTagSets, ai_ReadPreference_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(ReadPreference, bsonSerialize, ai_ReadPreference_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
 	PHP_FE_END
+	/* clang-format on */
 };
 /* }}} */
 
 /* {{{ MongoDB\Driver\ReadPreference object handlers */
 static zend_object_handlers php_phongo_handler_readpreference;
 
-static void php_phongo_readpreference_free_object(phongo_free_object_arg *object TSRMLS_DC) /* {{{ */
+static void php_phongo_readpreference_free_object(phongo_free_object_arg* object TSRMLS_DC) /* {{{ */
 {
-	php_phongo_readpreference_t *intern = Z_OBJ_READPREFERENCE(object);
+	php_phongo_readpreference_t* intern = Z_OBJ_READPREFERENCE(object);
 
 	zend_object_std_dtor(&intern->std TSRMLS_CC);
 
+	if (intern->properties) {
+		zend_hash_destroy(intern->properties);
+		FREE_HASHTABLE(intern->properties);
+	}
+
 	if (intern->read_preference) {
 		mongoc_read_prefs_destroy(intern->read_preference);
 	}
@@ -250,9 +349,9 @@ static void php_phongo_readpreference_free_object(phongo_free_object_arg *object
 #endif
 } /* }}} */
 
-static phongo_create_object_retval php_phongo_readpreference_create_object(zend_class_entry *class_type TSRMLS_DC) /* {{{ */
+static phongo_create_object_retval php_phongo_readpreference_create_object(zend_class_entry* class_type TSRMLS_DC) /* {{{ */
 {
-	php_phongo_readpreference_t *intern = NULL;
+	php_phongo_readpreference_t* intern = NULL;
 
 	intern = PHONGO_ALLOC_OBJECT_T(php_phongo_readpreference_t, class_type);
 
@@ -274,21 +373,15 @@ static phongo_create_object_retval php_phongo_readpreference_create_object(zend_
 #endif
 } /* }}} */
 
-static HashTable *php_phongo_readpreference_get_debug_info(zval *object, int *is_temp TSRMLS_DC) /* {{{ */
+static HashTable* php_phongo_readpreference_get_debug_info(zval* object, int* is_temp TSRMLS_DC) /* {{{ */
 {
-#if PHP_VERSION_ID >= 70000
-	zval                       retval;
-#else
-	zval                       retval = zval_used_for_init;
-#endif
-	const mongoc_read_prefs_t *read_prefs = phongo_read_preference_from_zval(object TSRMLS_CC);
-
-
 	*is_temp = 1;
+	return php_phongo_readpreference_get_properties_hash(object, true TSRMLS_CC);
+} /* }}} */
 
-	php_phongo_read_preference_to_zval(&retval, read_prefs);
-
-	return Z_ARRVAL(retval);
+static HashTable* php_phongo_readpreference_get_properties(zval* object TSRMLS_DC) /* {{{ */
+{
+	return php_phongo_readpreference_get_properties_hash(object, false TSRMLS_CC);
 } /* }}} */
 /* }}} */
 
@@ -297,7 +390,7 @@ void php_phongo_readpreference_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	zend_class_entry ce;
 
 	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\Driver", "ReadPreference", php_phongo_readpreference_me);
-	php_phongo_readpreference_ce = zend_register_internal_class(&ce TSRMLS_CC);
+	php_phongo_readpreference_ce                = zend_register_internal_class(&ce TSRMLS_CC);
 	php_phongo_readpreference_ce->create_object = php_phongo_readpreference_create_object;
 	PHONGO_CE_FINAL(php_phongo_readpreference_ce);
 	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_readpreference_ce);
@@ -306,9 +399,10 @@ void php_phongo_readpreference_init_ce(INIT_FUNC_ARGS) /* {{{ */
 
 	memcpy(&php_phongo_handler_readpreference, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
 	php_phongo_handler_readpreference.get_debug_info = php_phongo_readpreference_get_debug_info;
+	php_phongo_handler_readpreference.get_properties = php_phongo_readpreference_get_properties;
 #if PHP_VERSION_ID >= 70000
 	php_phongo_handler_readpreference.free_obj = php_phongo_readpreference_free_object;
-	php_phongo_handler_readpreference.offset = XtOffsetOf(php_phongo_readpreference_t, std);
+	php_phongo_handler_readpreference.offset   = XtOffsetOf(php_phongo_readpreference_t, std);
 #endif
 
 	zend_declare_class_constant_long(php_phongo_readpreference_ce, ZEND_STRL("RP_PRIMARY"), MONGOC_READ_PRIMARY TSRMLS_CC);
