@@ -15,7 +15,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 #include <php.h>
@@ -24,14 +24,13 @@
 #include "phongo_compat.h"
 #include "php_phongo.h"
 
-zend_class_entry *php_phongo_writeerror_ce;
+zend_class_entry* php_phongo_writeerror_ce;
 
 /* {{{ proto integer MongoDB\Driver\WriteError::getCode()
    Returns the MongoDB error code */
 static PHP_METHOD(WriteError, getCode)
 {
-	php_phongo_writeerror_t  *intern;
-
+	php_phongo_writeerror_t* intern;
 
 	intern = Z_WRITEERROR_OBJ_P(getThis());
 
@@ -39,7 +38,6 @@ static PHP_METHOD(WriteError, getCode)
 		return;
 	}
 
-
 	RETURN_LONG(intern->code);
 } /* }}} */
 
@@ -48,8 +46,7 @@ static PHP_METHOD(WriteError, getCode)
    corresponds. */
 static PHP_METHOD(WriteError, getIndex)
 {
-	php_phongo_writeerror_t  *intern;
-
+	php_phongo_writeerror_t* intern;
 
 	intern = Z_WRITEERROR_OBJ_P(getThis());
 
@@ -57,7 +54,6 @@ static PHP_METHOD(WriteError, getIndex)
 		return;
 	}
 
-
 	RETURN_LONG(intern->index);
 } /* }}} */
 
@@ -65,8 +61,7 @@ static PHP_METHOD(WriteError, getIndex)
    Returns the actual error message from the server */
 static PHP_METHOD(WriteError, getMessage)
 {
-	php_phongo_writeerror_t  *intern;
-
+	php_phongo_writeerror_t* intern;
 
 	intern = Z_WRITEERROR_OBJ_P(getThis());
 
@@ -74,7 +69,6 @@ static PHP_METHOD(WriteError, getMessage)
 		return;
 	}
 
-
 	PHONGO_RETURN_STRING(intern->message);
 } /* }}} */
 
@@ -82,8 +76,7 @@ static PHP_METHOD(WriteError, getMessage)
    Returns additional metadata for the error */
 static PHP_METHOD(WriteError, getInfo)
 {
-	php_phongo_writeerror_t *intern;
-
+	php_phongo_writeerror_t* intern;
 
 	intern = Z_WRITEERROR_OBJ_P(getThis());
 
@@ -91,7 +84,6 @@ static PHP_METHOD(WriteError, getInfo)
 		return;
 	}
 
-
 	if (!Z_ISUNDEF(intern->info)) {
 #if PHP_VERSION_ID >= 70000
 		RETURN_ZVAL(&intern->info, 1, 0);
@@ -106,22 +98,24 @@ ZEND_BEGIN_ARG_INFO_EX(ai_WriteError_void, 0, 0, 0)
 ZEND_END_ARG_INFO()
 
 static zend_function_entry php_phongo_writeerror_me[] = {
-	PHP_ME(WriteError, getCode, ai_WriteError_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(WriteError, getIndex, ai_WriteError_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(WriteError, getMessage, ai_WriteError_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	PHP_ME(WriteError, getInfo, ai_WriteError_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
-	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_WriteError_void, ZEND_ACC_PRIVATE|ZEND_ACC_FINAL)
-	ZEND_NAMED_ME(__wakeup, PHP_FN(MongoDB_disabled___wakeup), ai_WriteError_void, ZEND_ACC_PUBLIC|ZEND_ACC_FINAL)
+	/* clang-format off */
+	PHP_ME(WriteError, getCode, ai_WriteError_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(WriteError, getIndex, ai_WriteError_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(WriteError, getMessage, ai_WriteError_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	PHP_ME(WriteError, getInfo, ai_WriteError_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
+	ZEND_NAMED_ME(__construct, PHP_FN(MongoDB_disabled___construct), ai_WriteError_void, ZEND_ACC_PRIVATE | ZEND_ACC_FINAL)
+	ZEND_NAMED_ME(__wakeup, PHP_FN(MongoDB_disabled___wakeup), ai_WriteError_void, ZEND_ACC_PUBLIC | ZEND_ACC_FINAL)
 	PHP_FE_END
+	/* clang-format on */
 };
 /* }}} */
 
 /* {{{ MongoDB\Driver\WriteError object handlers */
 static zend_object_handlers php_phongo_handler_writeerror;
 
-static void php_phongo_writeerror_free_object(phongo_free_object_arg *object TSRMLS_DC) /* {{{ */
+static void php_phongo_writeerror_free_object(phongo_free_object_arg* object TSRMLS_DC) /* {{{ */
 {
-	php_phongo_writeerror_t *intern = Z_OBJ_WRITEERROR(object);
+	php_phongo_writeerror_t* intern = Z_OBJ_WRITEERROR(object);
 
 	zend_object_std_dtor(&intern->std TSRMLS_CC);
 
@@ -138,9 +132,9 @@ static void php_phongo_writeerror_free_object(phongo_free_object_arg *object TSR
 #endif
 } /* }}} */
 
-static phongo_create_object_retval php_phongo_writeerror_create_object(zend_class_entry *class_type TSRMLS_DC) /* {{{ */
+static phongo_create_object_retval php_phongo_writeerror_create_object(zend_class_entry* class_type TSRMLS_DC) /* {{{ */
 {
-	php_phongo_writeerror_t *intern = NULL;
+	php_phongo_writeerror_t* intern = NULL;
 
 	intern = PHONGO_ALLOC_OBJECT_T(php_phongo_writeerror_t, class_type);
 
@@ -162,18 +156,13 @@ static phongo_create_object_retval php_phongo_writeerror_create_object(zend_clas
 #endif
 } /* }}} */
 
-static HashTable *php_phongo_writeerror_get_debug_info(zval *object, int *is_temp TSRMLS_DC) /* {{{ */
+static HashTable* php_phongo_writeerror_get_debug_info(zval* object, int* is_temp TSRMLS_DC) /* {{{ */
 {
-	php_phongo_writeerror_t *intern;
-#if PHP_VERSION_ID >= 70000
-	zval                     retval;
-#else
-	zval                     retval = zval_used_for_init;
-#endif
-
+	php_phongo_writeerror_t* intern;
+	zval                     retval = ZVAL_STATIC_INIT;
 
 	*is_temp = 1;
-	intern = Z_WRITEERROR_OBJ_P(object);
+	intern   = Z_WRITEERROR_OBJ_P(object);
 
 	array_init_size(&retval, 3);
 	ADD_ASSOC_STRING(&retval, "message", intern->message);
@@ -200,7 +189,7 @@ void php_phongo_writeerror_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	zend_class_entry ce;
 
 	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\Driver", "WriteError", php_phongo_writeerror_me);
-	php_phongo_writeerror_ce = zend_register_internal_class(&ce TSRMLS_CC);
+	php_phongo_writeerror_ce                = zend_register_internal_class(&ce TSRMLS_CC);
 	php_phongo_writeerror_ce->create_object = php_phongo_writeerror_create_object;
 	PHONGO_CE_FINAL(php_phongo_writeerror_ce);
 	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_writeerror_ce);
@@ -209,7 +198,7 @@ void php_phongo_writeerror_init_ce(INIT_FUNC_ARGS) /* {{{ */
 	php_phongo_handler_writeerror.get_debug_info = php_phongo_writeerror_get_debug_info;
 #if PHP_VERSION_ID >= 70000
 	php_phongo_handler_writeerror.free_obj = php_phongo_writeerror_free_object;
-	php_phongo_handler_writeerror.offset = XtOffsetOf(php_phongo_writeerror_t, std);
+	php_phongo_handler_writeerror.offset   = XtOffsetOf(php_phongo_writeerror_t, std);
 #endif
 } /* }}} */
 
