@@ -15,54 +15,54 @@
  */
 
 
-#include <bson.h>
-#include "mongoc-config.h"
+#include <bson/bson.h>
+#include "mongoc/mongoc-config.h"
 #ifdef MONGOC_HAVE_DNSAPI
 /* for DnsQuery_UTF8 */
 #include <Windows.h>
 #include <WinDNS.h>
 #include <ws2tcpip.h>
 #else
+#if defined(MONGOC_HAVE_RES_NSEARCH) || defined(MONGOC_HAVE_RES_SEARCH)
 #include <netdb.h>
 #include <netinet/tcp.h>
-#if defined(MONGOC_HAVE_RES_NSEARCH) || defined(MONGOC_HAVE_RES_SEARCH)
 #include <arpa/nameser.h>
 #include <resolv.h>
-#include <bson-string.h>
+#include <bson/bson-string.h>
 
 #endif
 #endif
 
-#include "mongoc-client-private.h"
-#include "mongoc-collection-private.h"
-#include "mongoc-counters-private.h"
-#include "mongoc-database-private.h"
-#include "mongoc-gridfs-private.h"
-#include "mongoc-error.h"
-#include "mongoc-log.h"
-#include "mongoc-queue-private.h"
-#include "mongoc-socket.h"
-#include "mongoc-stream-buffered.h"
-#include "mongoc-stream-socket.h"
-#include "mongoc-thread-private.h"
-#include "mongoc-trace-private.h"
-#include "mongoc-uri-private.h"
-#include "mongoc-util-private.h"
-#include "mongoc-set-private.h"
-#include "mongoc-log.h"
-#include "mongoc-write-concern-private.h"
-#include "mongoc-read-concern-private.h"
-#include "mongoc-host-list-private.h"
-#include "mongoc-read-prefs-private.h"
-#include "mongoc-change-stream-private.h"
-#include "mongoc-client-session-private.h"
-#include "mongoc-cursor-private.h"
+#include "mongoc/mongoc-client-private.h"
+#include "mongoc/mongoc-collection-private.h"
+#include "mongoc/mongoc-counters-private.h"
+#include "mongoc/mongoc-database-private.h"
+#include "mongoc/mongoc-gridfs-private.h"
+#include "mongoc/mongoc-error.h"
+#include "mongoc/mongoc-log.h"
+#include "mongoc/mongoc-queue-private.h"
+#include "mongoc/mongoc-socket.h"
+#include "mongoc/mongoc-stream-buffered.h"
+#include "mongoc/mongoc-stream-socket.h"
+#include "mongoc/mongoc-thread-private.h"
+#include "mongoc/mongoc-trace-private.h"
+#include "mongoc/mongoc-uri-private.h"
+#include "mongoc/mongoc-util-private.h"
+#include "mongoc/mongoc-set-private.h"
+#include "mongoc/mongoc-log.h"
+#include "mongoc/mongoc-write-concern-private.h"
+#include "mongoc/mongoc-read-concern-private.h"
+#include "mongoc/mongoc-host-list-private.h"
+#include "mongoc/mongoc-read-prefs-private.h"
+#include "mongoc/mongoc-change-stream-private.h"
+#include "mongoc/mongoc-client-session-private.h"
+#include "mongoc/mongoc-cursor-private.h"
 
 #ifdef MONGOC_ENABLE_SSL
-#include "mongoc-stream-tls.h"
-#include "mongoc-ssl-private.h"
-#include "mongoc-cmd-private.h"
-#include "mongoc-opts-private.h"
+#include "mongoc/mongoc-stream-tls.h"
+#include "mongoc/mongoc-ssl-private.h"
+#include "mongoc/mongoc-cmd-private.h"
+#include "mongoc/mongoc-opts-private.h"
 #endif
 
 
@@ -228,19 +228,25 @@ _mongoc_get_rr_dnsapi (const char *service,
    i = 0;
 
    do {
-      if (i > 0 && rr_type == MONGOC_RR_TXT) {
-         /* Initial DNS Seedlist Discovery Spec: a client "MUST raise an error
-          * when multiple TXT records are encountered". */
-         callback_success = false;
-         DNS_ERROR ("Multiple TXT records for \"%s\"", service);
+      /* DnsQuery can return additional records not of the requested type */
+      if ((rr_type == MONGOC_RR_TXT && pdns->wType == DNS_TYPE_TEXT) ||
+          (rr_type == MONGOC_RR_SRV && pdns->wType == DNS_TYPE_SRV)) {
+         if (i > 0 && rr_type == MONGOC_RR_TXT) {
+            /* Initial DNS Seedlist Discovery Spec: a client "MUST raise an
+            error when multiple TXT records are encountered". */
+            callback_success = false;
+            DNS_ERROR ("Multiple TXT records for \"%s\"", service);
+         }
+
+         if (!callback (service, pdns, uri, error)) {
+            callback_success = false;
+            GOTO (done);
+         }
+
+         i++;
       }
 
-      if (!callback (service, pdns, uri, error)) {
-         callback_success = false;
-         GOTO (done);
-      }
       pdns = pdns->pNext;
-      i++;
    } while (pdns);
 
 done:
@@ -2338,10 +2344,10 @@ mongoc_client_kill_cursor (mongoc_client_t *client, int64_t cursor_id)
    topology = client->topology;
    read_prefs = mongoc_read_prefs_new (MONGOC_READ_PRIMARY);
 
-   mongoc_mutex_lock (&topology->mutex);
+   bson_mutex_lock (&topology->mutex);
    if (!mongoc_topology_compatible (&topology->description, NULL, &error)) {
       MONGOC_ERROR ("Could not kill cursor: %s", error.message);
-      mongoc_mutex_unlock (&topology->mutex);
+      bson_mutex_unlock (&topology->mutex);
       mongoc_read_prefs_destroy (read_prefs);
       return;
    }
@@ -2357,7 +2363,7 @@ mongoc_client_kill_cursor (mongoc_client_t *client, int64_t cursor_id)
       server_id = selected_server->id;
    }
 
-   mongoc_mutex_unlock (&topology->mutex);
+   bson_mutex_unlock (&topology->mutex);
 
    if (server_id) {
       _mongoc_client_kill_cursor (client,
@@ -2564,11 +2570,11 @@ mongoc_client_get_server_descriptions (const mongoc_client_t *client,
    topology = client->topology;
 
    /* in case the client is pooled */
-   mongoc_mutex_lock (&topology->mutex);
+   bson_mutex_lock (&topology->mutex);
 
    sds = mongoc_topology_description_get_servers (&topology->description, n);
 
-   mongoc_mutex_unlock (&topology->mutex);
+   bson_mutex_unlock (&topology->mutex);
 
    return sds;
 }
